==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/dsl/camel-jbang/camel-jbang-core/src/test/java/org/apache/camel/dsl/jbang/core/commands/config/ConfigSetTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.dsl.jbang.core.commands.config;

import org.apache.camel.dsl.jbang.core.commands.CamelCommandBaseTest;
import org.apache.camel.dsl.jbang.core.commands.CamelJBangMain;
import org.apache.camel.dsl.jbang.core.commands.UserConfigHelper;
import org.apache.camel.dsl.jbang.core.common.CommandLineHelper;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

class ConfigSetTest extends CamelCommandBaseTest {

    @Test
    public void shouldSetConfig() throws Exception {
        UserConfigHelper.createUserConfig("");

        ConfigSet command = new ConfigSet(new CamelJBangMain().withPrinter(printer));
        command.configuration = "foo=bar";
        command.doCall();

        Assertions.assertEquals("", printer.getOutput());

        CommandLineHelper.loadProperties(properties -> {
            Assertions.assertEquals(1, properties.size());
            Assertions.assertEquals("bar", properties.get("foo"));
        });
    }

    @Test
    public void shouldOverwriteConfig() throws Exception {
        UserConfigHelper.createUserConfig("foo=bar");

        ConfigSet command = new ConfigSet(new CamelJBangMain().withPrinter(printer));
        command.configuration = "foo=baz";
        command.doCall();

        Assertions.assertEquals("", printer.getOutput());

        CommandLineHelper.loadProperties(properties -> {
            Assertions.assertEquals(1, properties.size());
            Assertions.assertEquals("baz", properties.get("foo"));
        });
    }

}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/dsl/camel-jbang/camel-jbang-core/src/test/java/org/apache/camel/dsl/jbang/core/commands/config/ConfigSetTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.dsl.jbang.core.commands.config;

import org.apache.camel.dsl.jbang.core.commands.CamelJBangMain;
import org.apache.camel.dsl.jbang.core.commands.UserConfigHelper;
import org.apache.camel.dsl.jbang.core.common.CommandLineHelper;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

class ConfigSetTest extends BaseConfigTest {

    @Test
    public void shouldSetConfig() throws Exception {
        UserConfigHelper.createUserConfig("");

        ConfigSet command = new ConfigSet(new CamelJBangMain().withPrinter(printer));
        command.configuration = "foo=bar";
        command.doCall();

        Assertions.assertEquals("", printer.getOutput());

        CommandLineHelper.loadProperties(properties -> {
            Assertions.assertEquals(1, properties.size());
            Assertions.assertEquals("bar", properties.get("foo"));
        });
    }

    @Test
    public void shouldOverwriteConfig() throws Exception {
        UserConfigHelper.createUserConfig("foo=bar");

        ConfigSet command = new ConfigSet(new CamelJBangMain().withPrinter(printer));
        command.configuration = "foo=baz";
        command.doCall();

        Assertions.assertEquals("", printer.getOutput());

        CommandLineHelper.loadProperties(properties -> {
            Assertions.assertEquals(1, properties.size());
            Assertions.assertEquals("baz", properties.get("foo"));
        });
    }

    @Test
    public void setLocalConfig() throws Exception {
        ConfigSet command = new ConfigSet(new CamelJBangMain().withPrinter(printer));
        command.configuration = "foo=local";
        command.global = false;
        command.doCall();

        Assertions.assertEquals("", printer.getOutput());

        CommandLineHelper.loadProperties(properties -> {
            Assertions.assertEquals(1, properties.size());
            Assertions.assertEquals("local", properties.get("foo"));
        }, true);
    }

}
